==> blink-components-0.4.0.tgz: package/.storybook/office2/home.js <==
// @flow

import React from 'react'
import { ThemeProvider } from 'react-css-themr'
import { Link, Element } from 'react-scroll'
import Markdown from 'react-markdown'
import Hero from 'components/Hero'
import Template from 'components/Template'
import Section from 'components/Section'
import Card from 'components/Card'
import OptIn from 'components/OptIn'
import Gallery from 'components/Gallery'
import theme from './theme'

import {
  optIn,
  navItems,
  sections,
  summary,
  images,
  heroBackground,
  services,
  places,
  languages,
  footer,
  copyright,
} from '../../sample-data/office'

const renderNavItem = item => (
  <Link key={item.to} className="white pointer mr3" smooth to={item.to}>
    {item.label}
  </Link>
)

const Home = () => (
  <ThemeProvider theme={theme}>
    <Template
      theme={theme}
      items={navItems}
      languages={languages}
      footer={footer}
      copyright={copyright}
      renderNavItem={renderNavItem}
    >
      <Hero
        backgroundImage="//res.cloudinary.com/connected/image/upload/w_960/v1495695823/hero-bg_apd51x.jpg"
        videos={[
          'https://connected.com.vn/dd1c6332a2f4fc69779b57f13e806fa5.mp4',
        ]}
      >
        <div className="bg-black-20 f3 pa3">
          This is the content with background
        </div>
      </Hero>
      <div className="w-100 flex flex-wrap">
        <div className="w-100 w-40-ns">
          <div className="ph3 pv3">
            <h1 className="-blue tc mb3 f3">{optIn.title}</h1>
            <h4 className="-blue tc f6 fw1 mb3">
              {optIn.subtitle}
            </h4>
            <OptIn
              requireName
              data={{
                isHorizontal: true,
                callToAction: optIn.callToAction,
              }}
              theme={{
                form: 'ph4-ns',
                body: 'ph4 ph0-ns mb4 mb2-ns',
                inputWrapper: 'bg-light-gray center ph2 pv2 ba b--light-gray mb2',
                icon: 'mr2 black-70',
                input: 'ph3 fw1 f6 black-70 bg-light-gray',
                callToAction: '-bg-orange fw9 tracked pt3 w-100 ph3 pv4 pv3-ns ph2-ns br2 bn outline-0 flex-none self-stretch white f5 f6-ns',
                errorWrapper: 'flex flex-wrap',
                error: 'dn',
              }}
            />
          </div>
        </div>
        <Section
          className="w-100 w-60-ns"
          {...sections.summary}
          theme={{
            body: 'center',
          }}
        >
          <Markdown source={summary} />
        </Section>
      </div>
      <Element name="summary">
        <Section
          {...sections.summary}
          theme={{
            body: 'mw8 center',
          }}
        >
          <Markdown source={summary} />
        </Section>
      </Element>
      <Element name="services">
        <Section
          {...sections.services}
          theme={{
            body: 'mw8 center',
          }}
        >
          <div className="flex flex-wrap">
            {services.map(item => (
              <div key={item.title} className="w-100 w-third-ns pa2">
                <Card key={item.title} item={item} />
              </div>
            ))}
          </div>
        </Section>
      </Element>
      <Element name="places">
        <Section
          {...sections.places}
          theme={{
            body: 'mw8 center',
          }}
        >
          <div className="flex flex-wrap">
            {places.map(item => (
              <div key={item.title} className="w-100 w-50-m w-25-l pa2">
                <Card
                  key={item.title}
                  item={item}
                  theme={{
                    image: 'br3',
                    title: 'f4',
                  }}
                />
              </div>
            ))}
          </div>
        </Section>
      </Element>
      <Element name="gallery">
        <Section
          className="w-100"
          {...sections.gallery}
        >
          <Gallery
            className="w-100 flex flex-wrap"
            images={images}
          />
        </Section>
      </Element>
    </Template>
  </ThemeProvider>
)

export default Home

==> blink-components-0.4.5.tgz: package/.storybook/office2/home.js <==
// @flow

import React from 'react'
import { ThemeProvider } from 'react-css-themr'
import { Element } from 'react-scroll'
import Markdown from 'react-markdown'
import Hero from 'components/Hero'
import Template from 'components/Template'
import Section from 'components/Section'
import Card from 'components/Card'
import OptIn from 'components/OptIn'
import Gallery from 'components/Gallery'
import theme from './theme.yml'

import {
  optIn,
  navItems,
  sections,
  summary,
  images,
  heroBackground,
  services,
  places,
  languages,
  footer,
  copyright,
} from '../../sample-data/office.yml'

const Home = () => (
  <ThemeProvider theme={theme}>
    <Template
      theme={theme}
      items={navItems}
      languages={languages}
      footer={footer}
      copyright={copyright}
    >
      <Hero
        backgroundImage={heroBackground}
        videos={[
          'https://connected.com.vn/dd1c6332a2f4fc69779b57f13e806fa5.mp4',
        ]}
      >
        <div className="bg-black-20 f3 pa3 white">
          This is the content with background
        </div>
      </Hero>
      <div className="w-100 flex flex-wrap">
        <div className="w-100 w-40-ns">
          <div className="ph3 pv3">
            <h1 className="-blue tc mb3 f3">{optIn.title}</h1>
            <h4 className="-blue tc f6 fw1 mb3">
              {optIn.subtitle}
            </h4>
            <OptIn
              requireName
              data={{
                isHorizontal: true,
                callToAction: optIn.callToAction,
              }}
              theme={{
                form: 'ph4-ns',
                body: 'ph4 ph0-ns mb4 mb2-ns',
                inputWrapper: 'bg-light-gray center ph2 pv2 ba b--light-gray mb2',
                icon: 'mr2 black-70',
                input: 'ph3 fw1 f6 black-70 bg-light-gray',
                callToAction: '-bg-orange fw9 tracked pt3 w-100 ph3 pv4 pv3-ns ph2-ns br2 bn outline-0 flex-none self-stretch white f5 f6-ns',
                errorWrapper: 'flex flex-wrap',
                error: 'dn',
              }}
            />
          </div>
        </div>
        <Section
          className="w-100 w-60-ns"
          {...sections.summary}
          theme={{
            body: 'center',
          }}
        >
          <Markdown source={summary} />
        </Section>
      </div>
      <Element name="summary">
        <Section
          {...sections.summary}
          theme={{
            body: 'mw8 center',
          }}
        >
          <Markdown source={summary} />
        </Section>
      </Element>
      <Element name="services">
        <Section
          {...sections.services}
          theme={{
            body: 'mw8 center',
          }}
        >
          <div className="flex flex-wrap">
            {services.map(item => (
              <div key={item.title} className="w-100 w-third-ns pa2">
                <Card key={item.title} item={item} />
              </div>
            ))}
          </div>
        </Section>
      </Element>
      <Element name="places">
        <Section
          {...sections.places}
          theme={{
            body: 'mw8 center',
          }}
        >
          <div className="flex flex-wrap">
            {places.map(item => (
              <div key={item.title} className="w-100 w-50-m w-25-l pa2">
                <Card
                  key={item.title}
                  item={item}
                  theme={{
                    image: 'br3',
                    title: 'f4',
                  }}
                />
              </div>
            ))}
          </div>
        </Section>
      </Element>
      <Element name="gallery">
        <Section
          className="w-100"
          {...sections.gallery}
        >
          <Gallery
            className="w-100 flex flex-wrap"
            images={images}
          />
        </Section>
      </Element>
    </Template>
  </ThemeProvider>
)

export default Home
